diff -u gdevnpdl/gdevnpdl.c gdevnpdl-gs2.x/gdevnpdl.c
--- gdevnpdl/gdevnpdl.c	Tue Sep 29 01:11:20 1998
+++ gdevnpdl-gs2.x/gdevnpdl.c	Tue Sep 29 01:11:31 1998
@@ -76,10 +76,12 @@
 
 /* The device descriptors */
 private dev_proc_open_device(npdl_open);
+private dev_proc_get_initial_matrix(npdl_get_initial_matrix);
 private dev_proc_print_page(npdl_print_page);
 
-private gx_device_procs prn_npdl_procs =
-  prn_procs(npdl_open, gdev_prn_output_page, gdev_prn_close);
+gx_device_procs prn_npdl_procs =
+  prn_matrix_procs(npdl_open, npdl_get_initial_matrix,
+		   gdev_prn_output_page, gdev_prn_close);
 
 gx_device_printer far_data gs_npdl_device =
   prn_device(prn_npdl_procs, "npdl",
@@ -371,38 +373,45 @@
 private int
 npdl_open(gx_device *dev)
 {
-    float margins[4];
-
     /* Change the margins according to the paper size. */
     switch(npdl_get_paper_size(dev)){
     case PAPER_SIZE_A5:
-	margins[0] = L_MARGIN_A5;
-	margins[1] = B_MARGIN_A5;
-	margins[2] = R_MARGIN_A5;
-	margins[3] = T_MARGIN_A5;
+	dev->l_margin = L_MARGIN_A5;
+	dev->b_margin = B_MARGIN_A5;
+	dev->r_margin = R_MARGIN_A5;
+	dev->t_margin = T_MARGIN_A5;
 	break;
     case PAPER_SIZE_B5:
-	margins[0] = L_MARGIN_B5;
-	margins[1] = B_MARGIN_B5;
-	margins[2] = R_MARGIN_B5;
-	margins[3] = T_MARGIN_B5;
+	dev->l_margin = L_MARGIN_B5;
+	dev->b_margin = B_MARGIN_B5;
+	dev->r_margin = R_MARGIN_B5;
+	dev->t_margin = T_MARGIN_B5;
 	break;
     case PAPER_SIZE_LETTER:
-	margins[0] = L_MARGIN_LETTER;
-	margins[1] = B_MARGIN_LETTER;
-	margins[2] = R_MARGIN_LETTER;
-	margins[3] = T_MARGIN_LETTER;
+	dev->l_margin = L_MARGIN_LETTER;
+	dev->b_margin = B_MARGIN_LETTER;
+	dev->r_margin = R_MARGIN_LETTER;
+	dev->t_margin = T_MARGIN_LETTER;
 	break;
     default:
-	margins[0] = L_MARGIN_A4;
-	margins[1] = B_MARGIN_A4;
-	margins[2] = R_MARGIN_A4;
-	margins[3] = T_MARGIN_A4;
+	dev->l_margin = L_MARGIN_A4;
+	dev->b_margin = B_MARGIN_A4;
+	dev->r_margin = R_MARGIN_A4;
+	dev->t_margin = T_MARGIN_A4;
 	break;
     }
-    gx_device_set_margins(dev, margins, true);
 
     return gdev_prn_open(dev);
+}
+
+/* Shift the origin from the top left corner of the physical page to the
+   first printable pixel, as defined by the top and left margins. */
+private void
+npdl_get_initial_matrix(gx_device *dev, gs_matrix *pmat)
+{
+    gx_default_get_initial_matrix(dev, pmat);
+    pmat->tx -= dev->l_margin * dev->x_pixels_per_inch;
+    pmat->ty -= dev->t_margin * dev->y_pixels_per_inch;
 }
 
 /* Send the page to the printer.  For speed, compress each scan line,
diff -u gdevnpdl/gdevnpdl.mak gdevnpdl-gs2.x/gdevnpdl.mak
--- gdevnpdl/gdevnpdl.mak	Tue Sep 29 01:06:20 1998
+++ gdevnpdl-gs2.x/gdevnpdl.mak	Tue Sep 29 01:06:40 1998
@@ -1,8 +1,8 @@
 ### ---------------- The NEC NPDL language printer device ---------------- ###
 
 npdl_=gdevnpdl.$(OBJ) gdevprn.$(OBJ)
-npdl.dev: $(npdl_) page.dev
-	$(SETPDEV) npdl $(npdl_)
+npdl.dev: $(npdl_)
+	$(SHP)gssetdev npdl $(npdl_)
 
 gdevnpdl.$(OBJ): gdevnpdl.c $(PDEVH)
 	$(CCC) gdevnpdl.c
